@@ -26,6 +26,8 @@ def load_graphml(input_data):
                 raise autonetkit.exception.AnkIncorrectFileFormat
             except IndexError:
                 raise autonetkit.exception.AnkIncorrectFileFormat
+        else:
+            raise e
 
     # remove selfloops
     graph.remove_edges_from(edge for edge in graph.selfloop_edges())
